#
# Copyright (c) 2015-2022 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyams_content.component.illustration import IIllustration
from pyams_content.features.renderer import IContentRenderer
from pyams_darkgreen_theme.layer import IPyAMSDarkGreenLayer
from pyams_default_theme.component.illustration import CenteredIllustrationRenderer, \
    DefaultIllustrationRenderer, \
    LeftIllustrationWithZoomRenderer as LeftIllustrationWithZoomRendererBase, \
    RightIllustrationWithZoomRenderer as RightIllustrationWithZoomRendererBase
from pyams_template.template import override_template, template_config
from pyams_utils.adapter import adapter_config


override_template(context=CenteredIllustrationRenderer,
                  template='templates/illustration-default.pt',
                  layer=IPyAMSDarkGreenLayer)


@adapter_config(name='left+zoom',
                context=(IIllustration, IPyAMSDarkGreenLayer),
                provides=IContentRenderer)
@template_config(template='templates/illustration-left.pt',
                 layer=IPyAMSDarkGreenLayer)
class LeftIllustrationWithZoomRenderer(LeftIllustrationWithZoomRendererBase):
    """Left illustration with zoom renderer"""

    resources = ()


@adapter_config(name='right+zoom',
                context=(IIllustration, IPyAMSDarkGreenLayer),
                provides=IContentRenderer)
@template_config(template='templates/illustration-right.pt',
                 layer=IPyAMSDarkGreenLayer)
class RightIllustrationWithZoomRenderer(RightIllustrationWithZoomRendererBase):
    """Right illustration with zoom renderer"""

    resources = ()


override_template(context=DefaultIllustrationRenderer,
                  template='templates/illustration-default.pt',
                  layer=IPyAMSDarkGreenLayer)
