#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.interface import implementer
from zope.location import Location
from zope.location.interfaces import ISublocations
from zope.schema.fieldproperty import FieldProperty

from pyams_darkgreen_theme.features.footer.interfaces import IDarkGreenThemeFooterLegalsMenu, \
    IDarkGreenThemeFooterMenusContainer, \
    IDarkGreenThemeFooterRendererSettings
from pyams_content.component.association.interfaces import ASSOCIATION_CONTAINER_KEY
from pyams_content.features.menu import IMenu, IMenusContainer, IMenusContainerTarget
from pyams_content.features.menu.interfaces import IMenuLinksContainer, IMenuLinksContainerTarget
from pyams_sequence.reference import get_reference_target
from pyams_utils.adapter import ContextAdapter, adapter_config, get_annotation_adapter


DARKGREEN_THEME_FOOTER_MENUS_KEY = '{0}::darkgreen::menus'.format(ASSOCIATION_CONTAINER_KEY)
DARKGREEN_THEME_FOOTER_LEGALS_KEY = '{0}::darkgreen::legals'.format(ASSOCIATION_CONTAINER_KEY)


@implementer(IDarkGreenThemeFooterRendererSettings, IMenusContainerTarget, IMenuLinksContainerTarget)
class DarkGreenThemeFooterRendererSettings(Persistent, Location):
    """DarkGreen theme footer persistent settings"""

    phone_number = FieldProperty(IDarkGreenThemeFooterRendererSettings['phone_number'])
    email = FieldProperty(IDarkGreenThemeFooterRendererSettings['email'])
    address = FieldProperty(IDarkGreenThemeFooterRendererSettings['address'])
    position = FieldProperty(IDarkGreenThemeFooterRendererSettings['position'])
    opening_hours = FieldProperty(IDarkGreenThemeFooterRendererSettings['opening_hours'])
    contact_form = FieldProperty(IDarkGreenThemeFooterRendererSettings['contact_form'])
    contact_form_context = FieldProperty(
        IDarkGreenThemeFooterRendererSettings['contact_form_context'])
    copyright = FieldProperty(IDarkGreenThemeFooterRendererSettings['copyright'])

    def get_contact_form_target(self):
        return get_reference_target(self.contact_form)

    def get_contact_form_context(self):
        return get_reference_target(self.contact_form_context)

    @property
    def menus(self):
        return get_annotation_adapter(self, DARKGREEN_THEME_FOOTER_MENUS_KEY, IMenusContainer,
                                      markers=IDarkGreenThemeFooterMenusContainer,
                                      name='++ass++menus')

    @property
    def legals(self):
        return get_annotation_adapter(self, DARKGREEN_THEME_FOOTER_LEGALS_KEY, IMenu,
                                      markers=IDarkGreenThemeFooterLegalsMenu,
                                      name='++ass++legals')


@adapter_config(name='menus',
                context=IDarkGreenThemeFooterRendererSettings,
                provides=IMenusContainer)
def  darkgreen_theme_footer_menus_adapter(context):
    """DarkGreen theme footer menus adapter"""
    return context.menus


@adapter_config(name='legals',
                context=IDarkGreenThemeFooterRendererSettings,
                provides=IMenuLinksContainer)
def  darkgreen_theme_footer_legals_adapter(context):
    """DarkGreen theme footer legals menus adapter"""
    return context.legals


@adapter_config(name='links',
                context=IDarkGreenThemeFooterRendererSettings,
                provides=ISublocations)
class DarkGreenThemeFooterRendererSettingsSublocations(ContextAdapter):
    """DarkGreen theme footer renderer settings sub-locations adapter"""

    def sublocations(self):
        return self.context.menus.values() + self.context.legals.values()
