#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.interface import implementer
from zope.location import Location
from zope.location.interfaces import ISublocations
from zope.schema.fieldproperty import FieldProperty

from pyams_darkgreen_theme.features.header.interfaces import IDarkGreenThemeHeaderMenusContainer, \
    IDarkGreenThemeHeaderRendererSettings
from pyams_content.component.association.interfaces import ASSOCIATION_CONTAINER_KEY
from pyams_content.features.menu import IMenusContainer, IMenusContainerTarget
from pyams_sequence.reference import get_reference_target
from pyams_utils.adapter import ContextAdapter, adapter_config, get_annotation_adapter


DARKGREEN_THEME_HEADER_MENUS_KEY = '{0}::darkgreen::menus'.format(ASSOCIATION_CONTAINER_KEY)


@implementer(IDarkGreenThemeHeaderRendererSettings, IMenusContainerTarget)
class DarkGreenThemeHeaderRendererSettings(Persistent, Location):
    """DarkGreen theme header renderer settings"""

    search_folder = FieldProperty(IDarkGreenThemeHeaderRendererSettings['search_folder'])

    @property
    def can_apply_on_root(self):
        return True

    @property
    def search_folder_target(self):
        return get_reference_target(self.search_folder)

    @property
    def menus(self):
        return get_annotation_adapter(self, DARKGREEN_THEME_HEADER_MENUS_KEY, IMenusContainer,
                                      markers=IDarkGreenThemeHeaderMenusContainer,
                                      name='++ass++menus')


@adapter_config(name='menus',
                context=IDarkGreenThemeHeaderRendererSettings,
                provides=IMenusContainer)
def  darkgreen_theme_header_menus_adapter(context):
    """DarkGreen theme header menus adapter"""
    return context.menus


@adapter_config(name='menus',
                context=IDarkGreenThemeHeaderRendererSettings,
                provides=ISublocations)
class DarkGreenThemeHeaderRendererSettingsSublocations(ContextAdapter):
    """DarkGreen theme header renderer settings sub-locations"""

    def sublocations(self):
        return self.context.menus.values()
