#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from z3c.form.field import Fields

from pyams_darkgreen_theme.features.header import IDarkGreenThemeHeaderMenusContainer, \
    IDarkGreenThemeHeaderRendererSettings
from pyams_content.features.header.zmi import HeaderSettingsRendererSettingsEditForm
from pyams_content.features.menu.zmi import IMenusView, MenusTable, MenusView
from pyams_form.interfaces.form import IInnerSubForm
from pyams_portal.interfaces import MANAGE_TEMPLATE_PERMISSION
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.adapter import adapter_config
from pyams_zmi.form import InnerAdminEditForm


__docformat__ = 'restructuredtext'

from pyams_darkgreen_theme import _


@adapter_config(name=' darkgreen-header-properties',
                context=(IDarkGreenThemeHeaderRendererSettings, IPyAMSLayer, HeaderSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
class DarkGreenThemeHeaderPropertiesEditForm(InnerAdminEditForm):
    """DarkGreen theme header properties edit form"""

    legend = None

    fields = Fields(IDarkGreenThemeHeaderRendererSettings)
    edit_permission = MANAGE_TEMPLATE_PERMISSION

    weight = 1


#
# Header menus table view
#

@adapter_config(name=' darkgreen-header-menus',
                context=(IDarkGreenThemeHeaderRendererSettings, IPyAMSLayer,
                         HeaderSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++menus',
                context=(IDarkGreenThemeHeaderMenusContainer, IPyAMSLayer),
                provides=IMenusView)
class DarkGreenThemeHeaderMenusView(MenusView):
    """DarkGreen theme header middle groups view"""

    title = _("Header menus")

    table_class = MenusTable
    weight = 10
