#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from zope.interface import Interface

from pyams_darkgreen_theme import pyams_darkgreen_theme
from pyams_darkgreen_theme.layer import IPyAMSDarkGreenLayer
from pyams_default_theme.page import BaseIndexPage, BasePreviewPage
from pyams_portal.views import PortalContextIndexPage
from pyams_skin.interfaces import ISkin
from pyams_skin.interfaces.resources import IResources
from pyams_template.template import override_layout, override_template
from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
from pyams_utils.registry import utility_config


__docformat__ = 'restructuredtext'

from pyams_darkgreen_theme import _


@utility_config(name='PyAMS dark green skin', provides=ISkin)
class PyAMSDarkGreenSkin:
    """PyAMS dark green skin"""

    label = _("PyAMS dark green skin")
    layer = IPyAMSDarkGreenLayer


@adapter_config(context=(Interface, IPyAMSDarkGreenLayer, Interface),
                provides=IResources)
class PyAMSDarkGreenLayerResources(ContextRequestViewAdapter):
    """PyAMS dark green layer resources adapter"""

    resources = (pyams_darkgreen_theme,)


override_layout(context=BaseIndexPage,
                template='templates/layout.pt',
                layer=IPyAMSDarkGreenLayer)

override_layout(context=BasePreviewPage,
                template='templates/preview-layout.pt',
                layer=IPyAMSDarkGreenLayer)

override_template(context=PortalContextIndexPage,
                  template='templates/portal-pagelet.pt',
                  layer=IPyAMSDarkGreenLayer)
